==> vue-icon-2.21.0.tgz: package/lib/loading-shadow.js <==
import { svg } from "@opentinyvue/vue-common";
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("svg", _vm._g({
    attrs: {
      "viewBox": "0 0 15.8 15.8",
      "xmlns": "http://www.w3.org/2000/svg"
    }
  }, _vm.$listeners), [_c("defs", {
    attrs: {
      "fill": "none"
    }
  }, [_c("linearGradient", {
    attrs: {
      "x1": "20.263",
      "y1": "7.9",
      "x2": "4.236",
      "y2": "0",
      "id": "loading-shadow_svg__a",
      "gradientUnits": "userSpaceOnUse"
    }
  }, [_c("stop", {
    attrs: {
      "offset": ".001",
      "stop-color": "#FFF",
      "stop-opacity": "0"
    }
  }), _c("stop", {
    attrs: {
      "offset": ".975",
      "stop-color": "#FFF"
    }
  })], 1)], 1), _c("mask", {
    attrs: {
      "fill": "none",
      "id": "loading-shadow_svg__b",
      "mask-type": "alpha",
      "maskUnits": "userSpaceOnUse",
      "x": "0",
      "y": "0"
    }
  }, [_c("path", {
    attrs: {
      "d": "M7.9 0c.49 0 .9.4.9.89 0 .5-.41.91-.9.91-3.37 0-6.1 2.73-6.1 6.09C1.8 11.26 4.53 14 7.9 14c3.36 0 6.1-2.74 6.1-6.11a.9.9 0 0 1 1.8 0c0 4.37-3.54 7.91-7.9 7.91-4.37 0-7.9-3.54-7.9-7.91C0 3.53 3.53 0 7.9 0Z",
      "fill": "url(#loading-shadow_svg__a)"
    }
  }, [_c("animateTransform", {
    attrs: {
      "attributeName": "transform",
      "attributeType": "XML",
      "type": "rotate",
      "from": "0 7.9 7.9",
      "to": "360 7.9 7.9",
      "dur": "1s",
      "repeatCount": "indefinite"
    }
  })], 1)]), _c("g", {
    attrs: {
      "mask": "url(#loading-shadow_svg__b)"
    }
  }, [_c("path", {
    attrs: {
      "d": "M-.1 15.89h16v-16h-16v16Z",
      "fill-rule": "evenodd"
    }
  })])]);
};
var LoadingShadow = {
  render
};
var index = function index2() {
  return svg({
    name: "IconLoadingShadow",
    component: LoadingShadow
  })();
};
export {
  index as default
};

==> vue-icon-2.25.0.tgz: package/lib/loading-shadow.js <==
import { svg } from "@opentinyvue/vue-common";
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("svg", _vm._g({
    attrs: {
      "xmlns": "http://www.w3.org/2000/svg",
      "viewBox": "0 0 32 32"
    }
  }, _vm.$listeners), [_c("defs", {
    attrs: {
      "fill": "none"
    }
  }, [_c("linearGradient", {
    attrs: {
      "id": "loading-shadow_svg__a",
      "x1": "-1285.88",
      "y1": "25.63",
      "x2": "-1286.89",
      "y2": "25.13",
      "gradientTransform": "matrix(29.6 0 0 29.6 38096.4 -732.8)",
      "gradientUnits": "userSpaceOnUse"
    }
  }, [_c("stop", {
    attrs: {
      "offset": "0",
      "stop-color": "#191919",
      "stop-opacity": "0"
    }
  }), _c("stop", {
    attrs: {
      "offset": "1",
      "stop-color": "#191919"
    }
  })], 1)], 1), _c("mask", {
    attrs: {
      "fill": "none",
      "id": "loading-shadow_svg__b",
      "mask-type": "alpha",
      "maskUnits": "userSpaceOnUse",
      "x": "0",
      "y": "0"
    }
  }, [_c("path", {
    attrs: {
      "fill": "url(#loading-shadow_svg__a)",
      "d": "M16 1.2c1 0 1.8.8 1.8 1.8S17 4.8 16 4.8C9.8 4.8 4.8 9.8 4.8 16s5 11.2 11.2 11.2 11.2-5 11.2-11.2c0-1 .8-1.8 1.8-1.8s1.8.8 1.8 1.8c0 8.2-6.6 14.8-14.8 14.8S1.2 24.2 1.2 16 7.8 1.2 16 1.2Z"
    }
  }, [_c("animateTransform", {
    attrs: {
      "attributeName": "transform",
      "attributeType": "XML",
      "type": "rotate",
      "from": "0 16 16",
      "to": "360 16 16",
      "dur": "1s",
      "repeatCount": "indefinite"
    }
  })], 1)]), _c("g", {
    attrs: {
      "mask": "url(#loading-shadow_svg__b)"
    }
  }, [_c("path", {
    attrs: {
      "d": "M-.1 32H32V-.11H-.1V32Z",
      "fill-rule": "evenodd"
    }
  })])]);
};
var LoadingShadow = {
  render
};
var index = function index2() {
  return svg({
    name: "IconLoadingShadow",
    component: LoadingShadow
  })();
};
export {
  index as default
};
